==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_uh = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_uu = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };

==> igniteui-angular-charts-16.0.0.tgz: package/esm5/lib/NegativeVolumeIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { NegativeVolumeIndexIndicatorStrategy } from "./NegativeVolumeIndexIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var NegativeVolumeIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NegativeVolumeIndexIndicator, _super);
    function NegativeVolumeIndexIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NegativeVolumeIndexIndicator.prototype.get_ul = function () {
        return new NegativeVolumeIndexIndicatorStrategy();
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.prototype.get_uy = function () {
        return NegativeVolumeIndexIndicator.$;
    };
    Object.defineProperty(NegativeVolumeIndexIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    NegativeVolumeIndexIndicator.$t = markType(NegativeVolumeIndexIndicator, 'NegativeVolumeIndexIndicator', StrategyBasedIndicator.$);
    return NegativeVolumeIndexIndicator;
}(StrategyBasedIndicator));
export { NegativeVolumeIndexIndicator };
